package com.xinelu.manage.controller.project;

import com.xinelu.common.annotation.Log;
import com.xinelu.common.core.controller.BaseController;
import com.xinelu.common.core.domain.AjaxResult;
import com.xinelu.common.core.page.TableDataInfo;
import com.xinelu.common.enums.BusinessType;
import com.xinelu.common.utils.poi.ExcelUtil;
import com.xinelu.manage.domain.project.Project;
import com.xinelu.manage.service.project.IProjectService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 检测项目Controller
 *
 * @author haown
 * @date 2024-03-11
 */
@Api(tags = "检测项目控制器")
@RestController
@RequestMapping("/manage/project")
public class ProjectController extends BaseController {
    @Resource
    private IProjectService projectService;

	/**
	 * 查询检测项目列表
	 */
	@ApiOperation("分页查询检测项目列表")
	@PreAuthorize("@ss.hasPermi('manage:project:list')")
	@GetMapping("/list")
    public TableDataInfo list(Project project) {
        startPage();
        List<Project> list = projectService.selectProjectList(project);
        return getDataTable(list);
    }

    /**
     * 导出检测项目列表
     */
    @PreAuthorize("@ss.hasPermi('manage:project:export')")
    @Log(title = "检测项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Project project) {
        List<Project> list = projectService.selectProjectList(project);
        ExcelUtil<Project> util = new ExcelUtil<Project>(Project. class);
        util.exportExcel(response, list, "检测项目数据");
    }

    /**
     * 获取检测项目详细信息
     */
    @ApiOperation("根据id获取检测项目详细信息")
    @PreAuthorize("@ss.hasPermi('manage:project:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(projectService.selectProjectById(id));
    }

    /**
     * 新增检测项目
     */
    @ApiOperation("新增检测项目")
    @PreAuthorize("@ss.hasPermi('manage:project:add')")
    @Log(title = "检测项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Project project) {
        return toAjax(projectService.insertProject(project));
    }

    /**
     * 修改检测项目
     */
    @ApiOperation("修改检测项目")
    @PreAuthorize("@ss.hasPermi('manage:project:edit')")
    @Log(title = "检测项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Project project) {
        return toAjax(projectService.updateProject(project));
    }

    /**
     * 删除检测项目
     */
    @ApiOperation("批量删除检测项目")
    @PreAuthorize("@ss.hasPermi('manage:project:remove')")
    @Log(title = "检测项目", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(projectService.deleteProjectByIds(ids));
    }
}
